@@ -51,8 +51,12 @@ class SendGrid(object):
                 "get": "/apiv2/customer.ip.json"},
             "apps":{
                 "activate": "/apiv2/customer.apps.json",
-                "customize": "/apiv2/customer.apps.json"
-            }
+                "customize": "/apiv2/customer.apps.json"},
+            "category":{
+                "create": "/api/newsletter/category/create.json",
+                "del": "/api/newsletter/category/remove.json",
+                "list": "/api/newsletter/category/list.json",
+                "add": "/api/newsletter/category/add.json"}
         }
 
     def build_params(self, d=None):
@@ -201,12 +205,23 @@ class SendGrid(object):
     def add_sendip(self, **fields):
         '''Fields can be task, user, set, ip'''
         return self.call('sendip', 'add', dict(task="append", **fields))
+
     def activate_app(self, user, name):
         return self.call('apps', 'activate', dict(task="activate", user=user, name=name))
+
     def customize_app(self, user, name, settings):
         return self.call('apps', 'customize',
             dict(task="setup", user=user, name=name, **settings))
 
+    def add_category(self, category, name):
+        return self.call('category', 'add', dict(category=category, name=name))
+
+    def create_category(self, category):
+        return self.call('category', 'create', dict(category=category))
+
+    def del_category(self, category, name):
+        return self.call('category', 'del', dict(category=category, name=name))
+
     def warm_up_from_csv(self,
                         csv_path,  # name, email csv string (no header)
                         newsletter_name,  # existing newsletter_name to be cloned
